@@ -1,10 +1,7 @@
-extern "C" {
-
 #include <R.h>
 #include <Rinternals.h>
 #include <Rdefines.h>
 #include <R_ext/RS.h>
 #include <R_ext/Lapack.h>
 
-SEXP lambda(SEXP x);
-}
+extern "C" SEXP lambda(SEXP x); 
